<?php

namespace DigiComp\HetznerDnsApi;

use Composer\Pcre\Preg;
use Http\Client\Common\Plugin;
use Http\Promise\Promise;
use Psr\Http\Message\RequestInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\StreamFactoryInterface;

/**
 * This modifies Hetzners replies, to have a consistent time format in its responses
 *
 * 2020-04-07 01:53:30.065529651 +0000 UTC m=+602.191901972
 * 2020-04-07 01:53:30.065 +0000 UTC
 *
 * are replaced with:
 *
 * 2020-04-07 01:53:30 +0000 UTC
 */
class RewriteHetznerDatesPlugin implements Plugin
{
    /**
     * @var StreamFactoryInterface
     */
    protected StreamFactoryInterface $contentStreamFactory;

    /**
     * @param StreamFactoryInterface $contentStreamFactory
     */
    public function __construct(StreamFactoryInterface $contentStreamFactory)
    {
        $this->contentStreamFactory = $contentStreamFactory;
    }

    public function handleRequest(RequestInterface $request, callable $next, callable $first): Promise
    {
        return $next($request)->then(function (ResponseInterface $response) use ($request) {
            $oldContent = $response->getBody()->getContents();
            $newContent = Preg::replace(
                '~(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2})\.\d+ (\+\d{4} \w+)( [^"]*)?~m',
                '\\1 \\2',
                $oldContent
            );
            $newContent = Preg::replace('~"verified":""~', '"verified":null', $newContent);
            $newBody = $this->contentStreamFactory->createStream($newContent);

            return $response->withBody($newBody);
        });
    }
}
